#ifndef CALL_H
#define CALL_H

#include <QDateTime>
#include <QObject>

#include "fly-phone-db-client_global.h"

namespace FlyPhone {

class FLYPHONEDBCLIENTSHARED_EXPORT Call : public QObject
{
    Q_OBJECT
    Q_PROPERTY(int id MEMBER m_id NOTIFY idChanged)
    Q_PROPERTY(int duration MEMBER m_duration NOTIFY durationChanged)
    Q_PROPERTY(QString contactText MEMBER m_contactText NOTIFY contactTextChanged)
    Q_PROPERTY(QString contactId MEMBER m_contactId NOTIFY contactIdChanged)
    Q_PROPERTY(QDateTime date MEMBER m_date NOTIFY dateChanged)
    Q_PROPERTY(CallType type MEMBER m_type NOTIFY typeChanged)
    Q_ENUMS(CallType)

public:
    enum CallType { IncomingCall = 0, OutgoingCall, MissedCall, InvalidCall };

    explicit Call(QObject *parent = 0);
    ~Call();

    int id() const;
    void setId(int id);

    QString contactText() const;
    void setContactText(const QString &contactText);

    QString contactId() const;
    void setContactId(const QString &contactId);

    QDateTime date() const;
    void setDate(const QDateTime &date);

    int duration() const;
    void setDuration(int duration);

    CallType type() const;
    void setType(const CallType &type);

signals:
    void idChanged();
    void durationChanged();
    void contactTextChanged();
    void contactIdChanged();
    void dateChanged();
    void typeChanged();

private:
    int m_id;
    int m_duration; // in seconds
    QString m_contactText;
    QString m_contactId;
    QDateTime m_date;
    CallType m_type;
};

}

#endif // CALL_H
