#ifndef CHAIN_H
#define CHAIN_H

#include <QDateTime>
#include <QObject>

#include "fly-phone-db-client_global.h"

namespace FlyPhone {

class FLYPHONEDBCLIENTSHARED_EXPORT Chain : public QObject
{
    Q_OBJECT
    Q_PROPERTY(int count MEMBER m_count NOTIFY countChanged)
    Q_PROPERTY(int chatType MEMBER m_chatType NOTIFY chatTypeChanged)
    Q_PROPERTY(QString id MEMBER m_id NOTIFY idChanged)
    Q_PROPERTY(QString contactId MEMBER m_contactId NOTIFY contactIdChanged)
    Q_PROPERTY(QString contactText MEMBER m_contactText NOTIFY contactTextChanged)
    Q_PROPERTY(QString draft MEMBER m_draft NOTIFY draftChanged)
    Q_PROPERTY(QString message MEMBER m_message NOTIFY messageChanged)
    Q_PROPERTY(QDateTime date MEMBER m_date NOTIFY dateChanged)

public:
    explicit Chain(int count,
                   int chatType,
                   QString id,
                   QString contactId,
                   QString contactText,
                   QString draft,
                   QString message,
                   QDateTime date,
                   QObject *parent = 0);
    ~Chain();

public slots:
    int getCount() const;
    QString getId() const;
    int getChatType() const;
    QString getContactId() const;
    QString getContactText() const;
    QString getDraft() const;
    QString getMessage() const;
    QDateTime getDate() const;

    void setCount(const int &count);
    void setMessage(const QString &message);
    void setDate(const QDateTime &date);

    void messageToDraft();

signals:
    void countChanged();
    void chatTypeChanged();
    void idChanged();
    void contactIdChanged();
    void contactTextChanged();
    void draftChanged();
    void messageChanged();
    void dateChanged();

private:
    int     m_count;        // messages count
    int     m_chatType;
    QString m_id;
    QString m_contactId;
    QString m_contactText;  // phone; name; etc
    QString m_draft;        // uncompleted message
    QString m_message;      // last message
    QDateTime m_date;       // last message date
};

}

#endif // CHAIN_H
