#ifndef CONTACT_H
#define CONTACT_H

#include <QString>
#include <QObject>
#include <QStringList>

#include "fly-phone-db-client_global.h"

namespace FlyPhone {

class FLYPHONEDBCLIENTSHARED_EXPORT Contact : public QObject
{
    Q_OBJECT
    Q_PROPERTY(bool isFavorite              MEMBER m_isFavorite         NOTIFY isFavoriteChanged)
    Q_PROPERTY(QString id                   MEMBER m_id                 NOTIFY idChanged)
    Q_PROPERTY(QString name                 MEMBER m_name               NOTIFY nameChanged)
    Q_PROPERTY(QString surname              MEMBER m_surname            NOTIFY surnameChanged)
    Q_PROPERTY(QString middlename           MEMBER m_middlename         NOTIFY middlenameChanged)
    Q_PROPERTY(QString fullname             MEMBER m_fullname           NOTIFY fullnameChanged)
    Q_PROPERTY(QString organization         MEMBER m_organization       NOTIFY organizationChanged)
    Q_PROPERTY(QString dateOfBirth          MEMBER m_dateOfBirth        NOTIFY dateOfBirthChanged)
    Q_PROPERTY(QString comment              MEMBER m_comment            NOTIFY commentChanged)
    Q_PROPERTY(QStringList phoneList        MEMBER m_phoneList          NOTIFY phoneListChanged)
    Q_PROPERTY(QStringList phoneGroupList   MEMBER m_phoneGroupList     NOTIFY phoneGroupListChanged)
    Q_PROPERTY(QStringList emailList        MEMBER m_emailList          NOTIFY emailListChanged)
    Q_PROPERTY(QStringList emailGroupList   MEMBER m_emailGroupList     NOTIFY emailGroupListChanged)
    Q_PROPERTY(QStringList addressList      MEMBER m_addressList        NOTIFY addressListChanged)
    Q_PROPERTY(QStringList addressGroupList MEMBER m_addressGroupList   NOTIFY addressGroupListChanged)
    Q_PROPERTY(QStringList linkList         MEMBER m_linkList           NOTIFY linkListChanged)
    Q_PROPERTY(QString customData           MEMBER m_customData         NOTIFY customDataChanged)

public:
    explicit Contact(QObject *parent = 0);
    explicit Contact(QString id, QString name, QString customData, QStringList phones, QObject *parent = 0);
    explicit Contact(QString id, QString name, QStringList emails, QObject *parent = 0);
    explicit Contact(const Contact & contact, QObject *parent = 0);
    Contact& operator=(const Contact &rv);
    ~Contact();

    QString toString() const;

    bool isFavorite() const;
    QString getId() const;
    QString getName() const;
    QString getSurname() const;
    QString getMiddlename() const;
    QString getFullname() const;
    QString getOrganization() const;
    QString getDateOfBirth() const;
    QString getComment() const;
    QString getCustomData() const;
    QStringList getPhoneList() const;
    QStringList getPhoneGroupList() const;
    QStringList getEmailList() const;
    QStringList getEmailGroupList() const;
    QStringList getAddressList() const;
    QStringList getAddressGroupList() const;
    QStringList getLinkList() const;

    void setIsFavorite(bool isFavorite);
    void setId(const QString &id);
    void setName(const QString &name);
    void setSurname(const QString &surname);
    void setMiddlename(const QString &middlename);
    void setFullname(const QString &fullname);
    void setOrganization(const QString &organization);
    void setDateOfBirth(const QString &dateOfBirth);
    void setComment(const QString &comment);
    void setCustomData(const QString &customData);
    void setPhoneList(const QStringList &phoneList);
    void setPhoneGroupList(const QStringList &phoneGroupList);
    void setEmailList(const QStringList &emailList);
    void setEmailGroupList(const QStringList &emailGroupList);
    void setAddressList(const QStringList &addressList);
    void setAddressGroupList(const QStringList &addressGroupList);
    void setLinkList(const QStringList &linkList);

public slots:
    void deleteLater();

signals:
    void idChanged();
    void isFavoriteChanged();
    void nameChanged();
    void surnameChanged();
    void middlenameChanged();
    void fullnameChanged();
    void organizationChanged();
    void dateOfBirthChanged();
    void commentChanged();
    void customDataChanged();
    void phoneListChanged();
    void phoneGroupListChanged();
    void emailListChanged();
    void emailGroupListChanged();
    void addressListChanged();
    void addressGroupListChanged();
    void linkListChanged();

private:
    bool        m_isFavorite;
    QString     m_id;
    QString     m_name;
    QString     m_surname;
    QString     m_middlename;
    QString     m_fullname;
    QString     m_organization;
    QString     m_dateOfBirth;
    QString     m_comment;
    QString     m_customData;
    QStringList m_phoneList;
    QStringList m_phoneGroupList;
    QStringList m_emailList;
    QStringList m_emailGroupList;
    QStringList m_addressList;
    QStringList m_addressGroupList;
    QStringList m_linkList;
};

}

#endif // CONTACT_H
