#ifndef MESSAGE_H
#define MESSAGE_H

#include <QDateTime>
#include <QObject>

#include "fly-phone-db-client_global.h"

namespace FlyPhone {

class FLYPHONEDBCLIENTSHARED_EXPORT Message : public QObject
{
    Q_OBJECT
    Q_PROPERTY(MessageStatus status MEMBER m_status NOTIFY statusChanged)
    Q_PROPERTY(QString id MEMBER m_id NOTIFY idChanged)
    Q_PROPERTY(QString chainId MEMBER m_chainId NOTIFY chainIdChanged)
    Q_PROPERTY(QString text MEMBER m_text NOTIFY textChanged)
    Q_PROPERTY(QDateTime date MEMBER m_date NOTIFY dateChanged)
    Q_ENUMS(MessageStatus)

public:
    enum MessageStatus { MessageNew = 0, MessageSent, MessageDelivered, MessageReceived, MessageError };

    explicit Message(MessageStatus status, QString id, QString chainId, QString text, QDateTime date, QObject *parent = 0);
    ~Message();

public slots:
    MessageStatus getStatus() const;
    QString getId() const;
    QString getChainId() const;
    QString getText() const;
    QDateTime getDate() const;
    QString getCustomData() const;
    QString getFrom() const;

    void setCustomData(const QString &customData);
    void setFrom(const QString &from);
    void setChainId(const QString &chainId);

signals:
    void statusChanged();
    void idChanged();
    void chainIdChanged();
    void textChanged();
    void dateChanged();

private:
    MessageStatus m_status;
    QString m_id;
    QString m_chainId;
    QString m_text;
    QString m_customData;
    QString m_from;
    QDateTime m_date;
};

}

#endif // MESSAGE_H
