#ifndef SQLITEDATABASE_H
#define SQLITEDATABASE_H

#include <QObject>
#include <QStringList>
#include <QVariant>

#include "fly-phone-db-client_global.h"

namespace FlyPhone {

class Contact;
class Chain;
class Message;
class Call;
class SqliteDatabasePrivate;

class FLYPHONEDBCLIENTSHARED_EXPORT SqliteDatabase : public QObject
{
    Q_OBJECT
    Q_ENUMS(ContactsDataType)

public:
    enum ContactsDataType { FullContactsDataType = 0, EmailContactsDataType, PhoneContactsDataType };

    explicit SqliteDatabase(QObject *parent = 0);
    ~SqliteDatabase();

    bool openDb(QString path = "");
    bool isOpen();

public slots:
    Contact * getContact(QString id = "", ContactsDataType contactsDataType = FullContactsDataType);
    QList <Contact *> getContacts(ContactsDataType contactsDataType = FullContactsDataType);
    QList <Chain *> getChains();
    QList <Message *> getMessages(QString chainId, QString fromId); // from not included
    QList <Call *> getCalls();
    Call * getCall(const int &id);
    QStringList getGroups();
    QVariantList getUnparsedMessages(); // WARNING: it removes it from db

    void addContact(Contact * contact); // TODO add fly-phone-dbus to all functions
    void addChain(Chain * chain);
    void addMessage(Message * message, bool justInsert = false);
    void addUnparsedMessage(const QString &phone, const QString &message);
    void addGroup(const QString &group);
    void addCall(Call * call);

    void updateContact(Contact * contact, ContactsDataType contactsDataType = FullContactsDataType);
    void updateChainLastMessage(QString chainId, QString messageId);
    void updateChainContact(QString chainId, QString contactId, QString contactText);
    void updateChainDraft(QString chainId, QString draft);
    void updateMessageStatus(QString messageId, int status);
    void updateCalls(const QString &contactId, const QString &phone);

    bool removeContacts(QStringList & idList);
    bool removeChain(QString id);
    bool removeMessage(QString id);
    bool removeGroup(const QString &group);
    bool removeCalls(const QList <int> &idList);

    void toggleFavorite(QString id);
    QByteArray getContactPhoto(const QString &id);
    void setContactPhoto(QString id, const QByteArray &photoData);

    int getMaxMessages() const;
    void setMaxMessages(const int &max);

    int getMaxCalls() const;
    void setMaxCalls(const int &max);

private:
    QList <Contact *> getContactsWithId(ContactsDataType contactsDataType = FullContactsDataType, QString id = "");

    Q_DECLARE_PRIVATE(SqliteDatabase)
    QScopedPointer <SqliteDatabasePrivate> d_ptr;
};

}

#endif // SQLITEDATABASE_H
